@@ -998,6 +998,32 @@ public class Quadro implements NinaEvent {
 		return options.get(s);
 	}
 
+	/**
+	 * 
+	 * @param s
+	 * @param n
+	 * @return
+	 */
+	public String getOptionNvl(String s, String n) {
+		String x = options.get(s);
+
+		return x != null ? x : n;
+	}
+
+	/**
+	 * 
+	 * @param s
+	 * @param x
+	 * @return
+	 */
+	public int getOptionInt(String s, int x) {
+		try {
+			return Integer.parseInt(options.get(s));
+		} catch(NumberFormatException e) {
+			return x;
+		}
+	}
+
 	/**
 	 * 
 	 * @param s
